@@ -86,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55b00
 #  endif
 #endif
 
@@ -169,6 +169,18 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KPARTS_DEPRECATED_VERSION_5_88(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_88(text)
+#endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KPARTS_DEPRECATED_VERSION_5_90(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
@@ -236,7 +248,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -246,7 +258,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55b00
 #  endif
 #endif
 
@@ -319,6 +331,18 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KPARTS_DEPRECATED_VERSION_5_88(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_88(text)
+#endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KPARTS_DEPRECATED_VERSION_5_90(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
